Module: Riagent::ActiveDocument::ClassMethods

Defined in:
lib/riagent/active_document.rb

Instance Method Summary collapse

Instance Method Details

#collection_nameObject

Returns string representation for the collection name Used to determine the RiakJson::Collection name, or the Riak Bucket name Uses ActiveModel::Naming functionality to derive the name



50
51
52
# File 'lib/riagent/active_document.rb', line 50

def collection_name
  self.model_name.plural
end